@@ -82,7 +82,8 @@
 #' versions)
 #' @param num_cycles the number of cycles of opimization. If set at Inf, it will
 #' do as many cycles as needed to meet the tolerance set for the target function.
-#' @param methode The method used in the ode solver, default is ode45
+#' @param methode The method used in the ode solver. This can be either 'analytical'
+#' for explicit matrix exponentation or any of the solvers in the deSolve package.
 #' @param correction Sets whether the correction should be applied (TRUE) or
 #' not (FALSE)
 #' @param verbose Show the parameters and loglikelihood for every call to the
@@ -137,7 +138,7 @@ dd_MS_ML = function(brtsM,
     changeloglikifnoconv = FALSE,
     optimmethod = 'subplex',
     num_cycles = 1,
-    methode = 'analytical',
+    methode = 'ode45',
     correction = FALSE,
     verbose = FALSE)
 {
